@@ -1,5 +1,5 @@
 *
-*    $Id: mvt.f 355 2019-06-19 09:59:17Z thothorn $
+*    $Id: mvt.f 575 2023-05-23 08:16:23Z thothorn $
 *
       SUBROUTINE MVTDST( N, NU, LOWER, UPPER, INFIN, CORREL, DELTA, 
      &                   MAXPTS, ABSEPS, RELEPS, ERROR, VALUE, INFORM )       
@@ -51,7 +51,7 @@
 *     INFORM INTEGER, termination status parameter:
 *            if INFORM = 0, normal completion with ERROR < EPS;
 *            if INFORM = 1, completion with ERROR > EPS and MAXPTS 
-*                           function vaules used; increase MAXPTS to 
+*                           function values used; increase MAXPTS to 
 *                           decrease ERROR;
 *            if INFORM = 2, N > 1000 or N < 1.
 *            if INFORM = 3, correlation matrix not positive semi-definite.
@@ -503,165 +503,6 @@
       END DO
       END
 *
-      DOUBLE PRECISION FUNCTION MVPHI(Z)
-*     
-*     Normal distribution probabilities accurate to 1d-15.
-*     Reference: J.L. Schonfelder, Math Comp 32(1978), pp 1232-1240. 
-*     
-      INTEGER I, IM
-      DOUBLE PRECISION A(0:43), BM, B, BP, P, RTWO, T, XA, Z
-      PARAMETER( RTWO = 1.414213562373095048801688724209D0, IM = 24 )
-      SAVE A
-      DATA ( A(I), I = 0, 43 )/
-     &    6.10143081923200417926465815756D-1,
-     &   -4.34841272712577471828182820888D-1,
-     &    1.76351193643605501125840298123D-1,
-     &   -6.0710795609249414860051215825D-2,
-     &    1.7712068995694114486147141191D-2,
-     &   -4.321119385567293818599864968D-3, 
-     &    8.54216676887098678819832055D-4, 
-     &   -1.27155090609162742628893940D-4,
-     &    1.1248167243671189468847072D-5, 3.13063885421820972630152D-7,      
-     &   -2.70988068537762022009086D-7, 3.0737622701407688440959D-8,
-     &    2.515620384817622937314D-9, -1.028929921320319127590D-9,
-     &    2.9944052119949939363D-11, 2.6051789687266936290D-11,
-     &   -2.634839924171969386D-12, -6.43404509890636443D-13,
-     &    1.12457401801663447D-13, 1.7281533389986098D-14, 
-     &   -4.264101694942375D-15, -5.45371977880191D-16,
-     &    1.58697607761671D-16, 2.0899837844334D-17, 
-     &   -5.900526869409D-18, -9.41893387554D-19, 2.14977356470D-19, 
-     &    4.6660985008D-20, -7.243011862D-21, -2.387966824D-21, 
-     &    1.91177535D-22, 1.20482568D-22, -6.72377D-25, -5.747997D-24,
-     &   -4.28493D-25, 2.44856D-25, 4.3793D-26, -8.151D-27, -3.089D-27, 
-     &    9.3D-29, 1.74D-28, 1.6D-29, -8.0D-30, -2.0D-30 /       
-*     
-      XA = ABS(Z)/RTWO
-      IF ( XA .GT. 100 ) THEN
-         P = 0
-      ELSE
-         T = ( 8*XA - 30 ) / ( 4*XA + 15 )
-         BM = 0
-         B  = 0
-         DO I = IM, 0, -1 
-            BP = B
-            B  = BM
-            BM = T*B - BP  + A(I)
-         END DO
-         P = EXP( -XA*XA )*( BM - BP )/4
-      END IF
-      IF ( Z .GT. 0 ) P = 1 - P
-      MVPHI = P
-      END
-*
-      DOUBLE PRECISION FUNCTION MVPHNV(P)
-*
-*	ALGORITHM AS241  APPL. STATIST. (1988) VOL. 37, NO. 3
-*
-*	Produces the normal deviate Z corresponding to a given lower
-*	tail area of P.
-*
-*	The hash sums below are the sums of the mantissas of the
-*	coefficients.   They are included for use in checking
-*	transcription.
-*
-      DOUBLE PRECISION SPLIT1, SPLIT2, CONST1, CONST2, 
-     *     A0, A1, A2, A3, A4, A5, A6, A7, B1, B2, B3, B4, B5, B6, B7, 
-     *     C0, C1, C2, C3, C4, C5, C6, C7, D1, D2, D3, D4, D5, D6, D7, 
-     *     E0, E1, E2, E3, E4, E5, E6, E7, F1, F2, F3, F4, F5, F6, F7, 
-     *     P, Q, R
-      PARAMETER ( SPLIT1 = 0.425, SPLIT2 = 5,
-     *            CONST1 = 0.180625D0, CONST2 = 1.6D0 )
-*     
-*     Coefficients for P close to 0.5
-*     
-      PARAMETER (
-     *     A0 = 3.38713 28727 96366 6080D0,
-     *     A1 = 1.33141 66789 17843 7745D+2,
-     *     A2 = 1.97159 09503 06551 4427D+3,
-     *     A3 = 1.37316 93765 50946 1125D+4,
-     *     A4 = 4.59219 53931 54987 1457D+4,
-     *     A5 = 6.72657 70927 00870 0853D+4,
-     *     A6 = 3.34305 75583 58812 8105D+4,
-     *     A7 = 2.50908 09287 30122 6727D+3,
-     *     B1 = 4.23133 30701 60091 1252D+1,
-     *     B2 = 6.87187 00749 20579 0830D+2,
-     *     B3 = 5.39419 60214 24751 1077D+3,
-     *     B4 = 2.12137 94301 58659 5867D+4,
-     *     B5 = 3.93078 95800 09271 0610D+4,
-     *     B6 = 2.87290 85735 72194 2674D+4,
-     *     B7 = 5.22649 52788 52854 5610D+3 )
-*     HASH SUM AB    55.88319 28806 14901 4439
-*     
-*     Coefficients for P not close to 0, 0.5 or 1.
-*     
-      PARAMETER (
-     *     C0 = 1.42343 71107 49683 57734D0,
-     *     C1 = 4.63033 78461 56545 29590D0,
-     *     C2 = 5.76949 72214 60691 40550D0,
-     *     C3 = 3.64784 83247 63204 60504D0,
-     *     C4 = 1.27045 82524 52368 38258D0,
-     *     C5 = 2.41780 72517 74506 11770D-1,
-     *     C6 = 2.27238 44989 26918 45833D-2,
-     *     C7 = 7.74545 01427 83414 07640D-4,
-     *     D1 = 2.05319 16266 37758 82187D0,
-     *     D2 = 1.67638 48301 83803 84940D0,
-     *     D3 = 6.89767 33498 51000 04550D-1,
-     *     D4 = 1.48103 97642 74800 74590D-1,
-     *     D5 = 1.51986 66563 61645 71966D-2,
-     *     D6 = 5.47593 80849 95344 94600D-4,
-     *     D7 = 1.05075 00716 44416 84324D-9 )
-*     HASH SUM CD    49.33206 50330 16102 89036
-*
-*	Coefficients for P near 0 or 1.
-*
-      PARAMETER (
-     *     E0 = 6.65790 46435 01103 77720D0,
-     *     E1 = 5.46378 49111 64114 36990D0,
-     *     E2 = 1.78482 65399 17291 33580D0,
-     *     E3 = 2.96560 57182 85048 91230D-1,
-     *     E4 = 2.65321 89526 57612 30930D-2,
-     *     E5 = 1.24266 09473 88078 43860D-3,
-     *     E6 = 2.71155 55687 43487 57815D-5,
-     *     E7 = 2.01033 43992 92288 13265D-7,
-     *     F1 = 5.99832 20655 58879 37690D-1,
-     *     F2 = 1.36929 88092 27358 05310D-1,
-     *     F3 = 1.48753 61290 85061 48525D-2,
-     *     F4 = 7.86869 13114 56132 59100D-4,
-     *     F5 = 1.84631 83175 10054 68180D-5,
-     *     F6 = 1.42151 17583 16445 88870D-7,
-     *     F7 = 2.04426 31033 89939 78564D-15 )
-*     HASH SUM EF    47.52583 31754 92896 71629
-*     
-      Q = ( 2*P - 1 )/2
-      IF ( ABS(Q) .LE. SPLIT1 ) THEN
-         R = CONST1 - Q*Q
-         MVPHNV = Q*( ( ( ((((A7*R + A6)*R + A5)*R + A4)*R + A3)
-     *                  *R + A2 )*R + A1 )*R + A0 )
-     *            /( ( ( ((((B7*R + B6)*R + B5)*R + B4)*R + B3)
-     *                  *R + B2 )*R + B1 )*R + 1 )
-      ELSE
-         R = MIN( P, 1 - P )
-         IF ( R .GT. 0 ) THEN
-            R = SQRT( -LOG(R) )
-            IF ( R .LE. SPLIT2 ) THEN
-               R = R - CONST2
-               MVPHNV = ( ( ( ((((C7*R + C6)*R + C5)*R + C4)*R + C3)
-     *                      *R + C2 )*R + C1 )*R + C0 ) 
-     *                /( ( ( ((((D7*R + D6)*R + D5)*R + D4)*R + D3)
-     *                      *R + D2 )*R + D1 )*R + 1 )
-            ELSE
-               R = R - SPLIT2
-               MVPHNV = ( ( ( ((((E7*R + E6)*R + E5)*R + E4)*R + E3)
-     *                      *R + E2 )*R + E1 )*R + E0 )
-     *                /( ( ( ((((F7*R + F6)*R + F5)*R + F4)*R + F3)
-     *                      *R + F2 )*R + F1 )*R + 1 )
-            END IF
-         ELSE
-            MVPHNV = 9
-         END IF
-         IF ( Q .LT. 0 ) MVPHNV = - MVPHNV
-      END IF
-      END
       DOUBLE PRECISION FUNCTION MVBVN( LOWER, UPPER, INFIN, CORREL )
 *
 *     A function for computing bivariate normal probabilities.
@@ -1407,7 +1248,7 @@
 *     Uniform (0,1) random number generator
 *
 *     use R's random number generator directly
-*     the way `Writing R extentions' advertises.
+*     the way `Writing R extensions' advertises.
 *
       DOUBLE PRECISION unifrnd, x
 
